@@ -184,7 +184,11 @@ class Experiment(object):
             self.redis.hset(self.key(), 'description', description)
 
     def get_description(self):
-        return self.redis.hget(self.key(), 'description')
+        description = self.redis.hget(self.key(), 'description')
+        if description:
+            return description.decode("utf-8", "replace")
+        else:
+            return None
 
     def reset(self):
         self.delete()
@@ -274,7 +278,7 @@ class Experiment(object):
         if not self._traffic_fraction:
             try:
                 self._traffic_fraction = float(self.redis.hget(self.key(), 'traffic_fraction'))
-            except TypeError:
+            except (TypeError, ValueError) as e:
                 self._traffic_fraction = 1
         return self._traffic_fraction
 
@@ -292,13 +296,22 @@ class Experiment(object):
             self._sequential_ids[client.client_id] = id_
         return self._sequential_ids[client.client_id]
 
-    def get_alternative(self, client, dt=None):
+    def get_alternative(self, client, alternative=None, dt=None):
+        """Returns and records an alternative according to the following
+        precedence:
+          1. An existing alternative
+          2. A client-chosen alternative
+          3. A server-chosen alternative
+        """
         if self.is_archived():
             return self.control
 
         chosen_alternative = self.existing_alternative(client)
         if not chosen_alternative:
-            chosen_alternative, participate = self.choose_alternative(client=client)
+            if alternative:
+                chosen_alternative, participate = Alternative(alternative, self, self.redis), True
+            else:
+                chosen_alternative, participate = self.choose_alternative(client=client)
             if participate:
                 chosen_alternative.record_participation(client, dt=dt)
 
