@@ -166,7 +166,7 @@ def find_or_404(experiment_name):
         if request.args.get('kpi'):
             exp.set_kpi(request.args.get('kpi'))
         return exp
-    except:
+    except ValueError:
         abort(404)
 
 
@@ -181,7 +181,6 @@ def determine_period():
 def simple_markdown(experiment):
     description = experiment['description']
     if description and description != '':
-        markdown(description)
         experiment['pretty_description'] = markdown(description)
     return experiment
 
